@@ -278,6 +278,10 @@ def honeycomb_armchair_ribbon(ntetramers=10):
   return g
 
 
+honeycomb_ribbon = honeycomb_armchair_ribbon # alias
+
+
+
 def square_ribbon(natoms):
   """ Creates the hamiltonian of a square ribbon lattice"""
   from numpy import array
@@ -1022,6 +1026,7 @@ def diamond_lattice_minimal():
   g.r = np.array(rs) # store
   g.r2xyz() # create r coordinates
   g.get_fractional()
+  g = sculpt.set_xy_plane(g) # a1 and a2 in the xy plane
   return g
 
 
